testtools.configure_multiple_voice_rhythmic_staves
==================================================

.. autofunction:: abjad.tools.testtools.configure_multiple_voice_rhythmic_staves.configure_multiple_voice_rhythmic_staves
   :noindex:
